#!/bin/sh

# Expects setup.bash to have been sourced, and <ext>/packages/$HADOOP_PREFIX to
# be unarchived
if [ -z "$GEXTPARALLELBUILDING" ]; then
    echo ""
    echo "Error! GEXTPARALLELBUILDING not set, run setup.bash in Parallel Building extension directory"
    echo ""
    exit 1
fi

if [ -z "$HADOOP_PREFIX" ]; then
    echo ""
    echo "Error! HADOOP_PREFIX not set, run setup.bash in Parallel Building extension directory"
    echo ""
    exit 1
fi

if [ ! -d $HADOOP_PREFIX ]; then
    echo ""
    echo "Error! Directory does not exist: $HADOOP_PREFIX"
    echo ""
    exit 1
fi

if [ ! -d "${GEXTPARALLELBUILDING}/packages/ThriftFS-0.9.0" ]; then
    echo ""
    echo "Error! ThriftFS package not found - has it been untarred?"
    echo ""
    exit 1
fi

# Default port number
PORT=58660
if [ -n "$1" ]; then
  PORT=$1
fi

# the hadoop configuration path
HADOOP_CONF_DIR=$HADOOP_PREFIX/conf/

CLASSPATH=${HADOOP_CONF_DIR}

# Hadoop, Apache, and other libraries (including Thrift in contribs compiled)
for f in ${HADOOP_PREFIX}/*.jar ; do
    CLASSPATH=$f:$CLASSPATH
done

# May include a HadoopThrift Server - but won't work with binary data
for f in ${HADOOP_PREFIX}/lib/*.jar ; do
    CLASSPATH=$f:$CLASSPATH
done

# Standard Thrift Libraries - maybe included above, but might as well be
# sure we have them
for f in ${GEXTPARALLELBUILDING}/packages/ThriftFS-0.9.0/lib/*.jar ; do
    CLASSPATH=$f:$CLASSPATH
done

# Customized HadoopThrift Server - must override any found in <hadoop>/lib
for f in ${GEXTPARALLELBUILDING}/packages/ThriftFS-0.9.0/*.jar ; do
    CLASSPATH=$f:$CLASSPATH
done

echo $CLASSPATH

java -Dcom.sun.management.jmxremote -cp $CLASSPATH org.apache.hadoop.thriftfs.HadoopThriftServer $PORT $*

